﻿Option Strict On
Imports System.IO.IsolatedStorage
Imports System.IO
'Imports Microsoft.Phone.Tasks
Imports System.Xml.Linq
'Imports System.Text

'■■削除対象ファイル選択のためのリスト用
Public Class DelYearMonth
    Property 年月 As String
End Class

Partial Public Class DeleteFiles
    Inherits PhoneApplicationPage

    Public Sub New()
        InitializeComponent()
    End Sub

    '■この削除ページがロードされた時の処理。年月リストの表示処理を実行する
    Private Sub DeleteFiles_Loaded(sender As Object, e As System.Windows.RoutedEventArgs) Handles MyBase.Loaded
        ShowHaikuList()
    End Sub

    '■保存済み俳句ファイルの年月リストをListBoxに表示する処理
    Private Sub ShowHaikuList()
        '●指定フォルダ内のXMLファイルのリストを取得
        Dim HaikuStorage_Del As IsolatedStorageFile = IsolatedStorageFile.GetUserStoreForApplication
        Dim HaikuFilePath_Del As String = Path.Combine("DailyHaiku_in_Japanese_Data", "*.xml")
        Dim HaikuFileList_Del() As String = HaikuStorage_Del.GetFileNames(HaikuFilePath_Del)

        '●ListBox表示用の年月リストを生成
        Dim HaikuMonthList_Del As New List(Of DelYearMonth)
        '●ファイル名の拡張子を除く部分を取得、このファイルの冒頭に記述しているDelYearMonthクラスを使い、リストに追加
        For Each MyXmlFileName In HaikuFileList_Del
            HaikuMonthList_Del.Add(New DelYearMonth With {.年月 = Path.GetFileNameWithoutExtension(MyXmlFileName)}) 'ファイル名を取得
        Next
        '●年月の追加されたリストを、ListBoxに適用
        DelMonthListBox.ItemsSource = HaikuMonthList_Del
    End Sub

    '■ListBoxから、削除したい月が選択された時の処理
    Private Sub DelMonthListBox_SelectionChanged(sender As System.Object, e As System.Windows.Controls.SelectionChangedEventArgs) Handles DelMonthListBox.SelectionChanged
        Try
            '●このファイルの冒頭に記述しているDelYearMonthクラスを使い、選択されたファイルの項目名（○年○月）を変数DelMonthNameに代入
            Dim DelMonthName As String = DirectCast(DelMonthListBox.SelectedItem, DelYearMonth).年月

            '●削除確認メッセージを表示
            Dim CheckRemove As MessageBoxResult = MessageBox.Show("ほんとうに削除してもよいですか？この操作を実行すると、この月の俳句データはすべて失われます。", DelMonthName & "の俳句ファイルを削除しますか？", MessageBoxButton.OKCancel)

            Select Case CheckRemove
                '●削除OKの場合の処理
                Case MessageBoxResult.OK
                    '●選択された月名に拡張子.xmlを追加して削除対象ファイル名とする
                    Dim DelMonthXml As XElement
                    Dim Storage_Del As IsolatedStorageFile = IsolatedStorageFile.GetUserStoreForApplication
                    Dim FilePath_Del As String = Path.Combine("DailyHaiku_in_Japanese_Data", DelMonthName & ".xml")

                    '●指定フォルダと当該ファイルが存在すれば、削除処理を実行
                    If Storage_Del.DirectoryExists("DailyHaiku_in_Japanese_Data") = True And Storage_Del.FileExists(FilePath_Del) = True Then

                        Dim MyStream_Del As IsolatedStorageFileStream = Storage_Del.OpenFile(FilePath_Del, FileMode.Open, FileAccess.Read)
                        Using Reader_Del As StreamReader = New StreamReader(MyStream_Del, System.Text.Encoding.UTF8)
                            Dim ReadDeleteXmldoc As String = Reader_Del.ReadToEnd
                            DelMonthXml = XElement.Parse(ReadDeleteXmldoc)
                            MyStream_Del.Close()
                        End Using

                        Storage_Del.DeleteFile(FilePath_Del)
                        MessageBox.Show(DelMonthName & "の俳句ファイルを削除しました。")
                        '●削除実行後、ListBox内の年月表示を更新する
                        ShowHaikuList()
                    Else
                        MessageBox.Show(DelMonthName & "の俳句ファイルはありません。")
                        Exit Sub
                    End If

                    Exit Select
                Case Else
                    '●削除しない場合の処理。ListBoxに年月を再バインド。この処理がなければ、同じ年月の再選択による削除が実行できない。
                    ShowHaikuList()
                    Exit Sub
            End Select
        Catch
            Exit Sub
        End Try
    End Sub
End Class
