﻿Option Strict On
Imports System.IO.IsolatedStorage
Imports System.IO
'Imports Microsoft.Phone.Tasks
Imports System.Xml.Linq
'Imports System.Text

Partial Public Class Preferences
    Inherits PhoneApplicationPage

    Public Sub New()
        InitializeComponent()
    End Sub

    '●投稿の可否に関わらず使う変数
    Dim Storage_Pre As IsolatedStorageFile
    Dim FilePath_Pre As String

    '■設定ページがロードされた時の処理
    Private Sub Preferences_Loaded(sender As Object, e As System.Windows.RoutedEventArgs) Handles MyBase.Loaded
        Storage_Pre = IsolatedStorageFile.GetUserStoreForApplication

        '●「DailyHaiku_Preferences」フォルダがなければ生成する
        If Storage_Pre.DirectoryExists("DailyHaiku_Preferences") = False Then
            Storage_Pre.CreateDirectory("DailyHaiku_Preferences")
        End If

        '●設定ファイルは、「DailyHaiku_Preferences」フォルダ内の「MyPreferences.xml」とする
        FilePath_Pre = Path.Combine("DailyHaiku_Preferences", "MyPreferences.xml")

        '●設定ファイルがあれば、facebook要素のTitle要素とLinkUri要素を取得、TextBox内に表示
        If Storage_Pre.FileExists(FilePath_Pre) = True Then
            Dim MyStream_Pre As IsolatedStorageFileStream = Storage_Pre.OpenFile(FilePath_Pre, FileMode.Open, FileAccess.Read)
            Dim Reader_Pre As StreamReader = New StreamReader(MyStream_Pre, System.Text.Encoding.UTF8)
            Dim ReadXmldoc_Pre As String = Reader_Pre.ReadToEnd
            Dim ItemDoc_Pre As XDocument = XDocument.Parse(ReadXmldoc_Pre)
            Reader_Pre.Close()
            MyStream_Pre.Close()

            Dim MyDataQuery_Pre As IEnumerable(Of XElement) = From c In ItemDoc_Pre.Descendants("facebook") Select c

            For Each MyResult_Pre In MyDataQuery_Pre
                LinkTitleText.Text = MyResult_Pre.<Title>.Value
                LinkURIText.Text = MyResult_Pre.<LinkUri>.Value
            Next
        End If

    End Sub

    '■「設定保存」ボタンがタップされた時の処理
    Private Sub SetPreferencesButton_Tap(sender As System.Object, e As System.Windows.Input.GestureEventArgs) Handles SetPreferencesButton.Tap

        '●入力ボックス内データを、生成するXMLのテキストとする
        Dim LinkTitle As String = LinkTitleText.Text
        Dim LinkUri As String = LinkURIText.Text

        '●入力ボックス内データの検証。Uriの形式が正しくなければ、入力ボックスの背景色を黄色にして注意を促す
        If LinkUri <> String.Empty Then
            If System.Text.RegularExpressions.Regex.IsMatch(LinkUri, "(ht|f)tp(s?)\:\/\/([\w-]+\.)+[\w-]+(/[\w- ./?%&=]*)?", System.Text.RegularExpressions.RegexOptions.IgnoreCase) Then
                LinkURIText.Background = New SolidColorBrush(Colors.White)
            Else
                MessageBox.Show("正しいURIが指定されているかどうか確認してください。")
                LinkURIText.Background = New SolidColorBrush(Colors.Yellow)
                Exit Sub
            End If
        Else
            MessageBox.Show("投稿機能をご利用になるには、リンク先アドレスを入力する必要があります。")
            Exit Sub
        End If


        '●設定ファイルの生成。既存ファイルがない場合は新規生成し、既にある場合はfacebook要素を追加していく。
        '●俳句の保存時には、最後のfacebook要素の内容を、最新設定として取得して、投稿する。
        If LinkTitle <> String.Empty Then
            Try
                If Storage_Pre.FileExists(FilePath_Pre) = False Then
                    Dim Xmldoc_Pre As XDocument = <?xml version="1.0" encoding="utf-8"?>
                                                  <Preferences>
                                                      <facebook>
                                                          <Title><%= LinkTitle %></Title>
                                                          <LinkUri><%= LinkUri %></LinkUri>
                                                      </facebook>
                                                  </Preferences>
                    Using MyStream_Pre As IsolatedStorageFileStream = New IsolatedStorageFileStream(FilePath_Pre, FileMode.Create, FileAccess.Write, Storage_Pre)
                        Xmldoc_Pre.Save(MyStream_Pre)
                        MessageBox.Show("俳句保存時にfacebookに投稿できるようになりました。")
                    End Using
                Else
                    Dim AddStream_Pre As IsolatedStorageFileStream = Storage_Pre.OpenFile(FilePath_Pre, FileMode.Open, FileAccess.Read)
                    Dim Reader_Pre As StreamReader = New StreamReader(AddStream_Pre)
                    Dim ReadXmldoc_Pre As String = Reader_Pre.ReadToEnd
                    Dim AddDoc_Pre As XElement = XElement.Parse(ReadXmldoc_Pre)
                    Dim AddXml_Pre As XElement = <facebook>
                                                     <Title><%= LinkTitle %></Title>
                                                     <LinkUri><%= LinkUri %></LinkUri>
                                                 </facebook>

                    AddDoc_Pre.Add(AddXml_Pre)
                    AddStream_Pre.Dispose()

                    Using Stream_Pre As IsolatedStorageFileStream = New IsolatedStorageFileStream(FilePath_Pre, FileMode.Create, FileAccess.Write, Storage_Pre)
                        If Storage_Pre.FileExists(FilePath_Pre) = True Then
                            AddDoc_Pre.Save(Stream_Pre)
                            Reader_Pre.Dispose()
                            MessageBox.Show("facebookへの投稿方法を設定しました。")
                        End If
                    End Using
                End If
            Catch
                Exit Sub
            End Try
        Else
            '●必須のタイトルが空の場合は、メッセージを表示
            MessageBox.Show("投稿機能をご利用になるには、タイトルとリンク先のアドレスの両方が必要です。")
            Exit Sub
        End If
    End Sub

    '■「投稿不要」ボタンがタップされた時の処理
    Private Sub DelPreferencesButton_Tap(sender As System.Object, e As System.Windows.Input.GestureEventArgs) Handles DelPreferencesButton.Tap

        '●設定ファイルを削除。既存設定ファイルがある場合は、フォルダは残したままファイルを削除する
        If Storage_Pre.DirectoryExists("DailyHaiku_Preferences") = True And Storage_Pre.FileExists(FilePath_Pre) = True Then
            Dim MyStream_Pre As IsolatedStorageFileStream = Storage_Pre.OpenFile(FilePath_Pre, FileMode.Open, FileAccess.Read)
            Using Reader_Pre As StreamReader = New StreamReader(MyStream_Pre, System.Text.Encoding.UTF8)
                Dim DeleteDoc_Pre As String = Reader_Pre.ReadToEnd
                Dim DelXml_Pre As XElement = XElement.Parse(DeleteDoc_Pre)
                MyStream_Pre.Close()
            End Using

            Storage_Pre.DeleteFile(FilePath_Pre)
            LinkTitleText.Text = "一日一句"
            LinkURIText.Text = "http://www."
            MessageBox.Show("facebookへの投稿設定情報を削除しました。")
        Else
            MessageBox.Show("投稿情報は設定されていません。")
        End If
    End Sub


End Class
