﻿Option Strict On
Imports System.IO.IsolatedStorage
Imports System.IO
Imports System.Xml.Linq

'■■俳句データ
Public Class MyTitleData
    Property 年月日 As String
    Property 俳句日 As String
    Property 俳句英 As String
End Class


Partial Public Class ShowHaiku
    Inherits PhoneApplicationPage

    Public Sub New()
        InitializeComponent()
    End Sub

    '■■選択された年月データを受け取る処理
    '●渡されるパラメータを受け取る変数を宣言
    Dim ReadMonth As String = String.Empty

    '●ListBoxから選択された「年月」を変数に代入
    Protected Overrides Sub OnNavigatedTo(ByVal e As System.Windows.Navigation.NavigationEventArgs)
        Dim MonthParam As IDictionary(Of String, String) = NavigationContext.QueryString
        ReadMonth = MonthParam("Name")
        MyBase.OnNavigatedTo(e)
    End Sub

    '●ソート処理対象のXML木を格納する変数を宣言
    Dim ShowHaikuItemDoc As XDocument

    '■この「一覧」ページがロードされた時の処理
    Private Sub ShowHaiku_Loaded(sender As Object, e As System.Windows.RoutedEventArgs) Handles MyBase.Loaded
        '●デフォルトは昇順表示なので、昇順ボタンを使用不可としておく
        SortAscendingButton.Opacity = 0.3
        SortAscendingButton.IsEnabled = False

        '●パラメータから渡された年月に拡張子.xmlを付けて処理対象ファイルとする
        Dim ShowHaikuStorage As IsolatedStorageFile = IsolatedStorageFile.GetUserStoreForApplication
        Dim ShowHaikuFilePath As String = Path.Combine("DailyHaiku_in_Japanese_Data", ReadMonth & ".xml")

        '●タイトルを表示
        SelectedMonth.Text = ReadMonth & "の俳句"

        '●ListBoxから選択されたファイルが存在する場合の処理。ファイルのXML木を読み込み、昇順ソート表示を実行する
        If ShowHaikuStorage.FileExists(ShowHaikuFilePath) = True Then
            Dim ShowHaikuStream As IsolatedStorageFileStream = ShowHaikuStorage.OpenFile(ShowHaikuFilePath, FileMode.Open, FileAccess.Read)
            Dim ShowHaikuReader As StreamReader = New StreamReader(ShowHaikuStream, System.Text.Encoding.UTF8)
            Dim ShowHaikuReadXmldoc As String = ShowHaikuReader.ReadToEnd
            ShowHaikuItemDoc = XDocument.Parse(ShowHaikuReadXmldoc)
            ShowHaikuReader.Close()
            ShowHaikuStream.Close()

            SortAscending()
            
        Else
            Exit Sub
        End If
    End Sub

    '■デフォルトの昇順ソート表示の処理
    Private Sub SortAscending()

        '●このファイルの冒頭に記述しているMyTitleDataクラスを使い、新規リストを生成
        Dim MyKuList As New List(Of MyTitleData)

        '●登録順、すなわち文書順に「俳句」要素を取得
        Dim MyDataQuery As IEnumerable(Of XElement) = From c In ShowHaikuItemDoc.Descendants("俳句") Order By c.@登録日時 Ascending

        '●「俳句」要素の「創作年月日」属性値、子要素の「英語句」「句」の内容を取得
        For Each MyResult In MyDataQuery

            Dim MyRecordDate As String = MyResult.@創作年月日
            Dim MyKuEnglish As String = MyResult.Elements("英語句").Value

            '●英語句が未入力の場合、改行文字列が入っている可能性があるので、見た目を整えるため空にしておく
            If MyKuEnglish.Length > 0 Then
                MyKuEnglish = MyKuEnglish
            Else
                MyKuEnglish = String.Empty
            End If

            Dim MyData As String = MyResult.Elements("句").Value

            '●生成したリストに、各々取得したデータを追加
            MyKuList.Add(New MyTitleData With {.年月日 = MyRecordDate, .俳句日 = MyData, .俳句英 = MyKuEnglish})
        Next
        '●ListBoxにデータを適用
        MyDailyHaikuListBox.ItemsSource = MyKuList
    End Sub

    '■降順ソート表示の処理
    Private Sub SortDescending()
        Dim MyKuList As New List(Of MyTitleData)

        '●登録日時の逆、すなわち逆文書順に「俳句」要素を取得。他の処理は昇順ソート表示に同じ
        Dim MyDataQuery As IEnumerable(Of XElement) = From c In ShowHaikuItemDoc.Descendants("俳句") Order By c.@登録日時 Descending
        For Each MyResult In MyDataQuery

            Dim MyRecordDate As String = MyResult.@創作年月日
            Dim MyKuEnglish As String = MyResult.Elements("英語句").Value

            If MyKuEnglish.Length > 0 Then
                MyKuEnglish = MyKuEnglish
            Else
                MyKuEnglish = String.Empty
            End If

            Dim MyData As String = MyResult.Elements("句").Value

            MyKuList.Add(New MyTitleData With {.年月日 = MyRecordDate, .俳句日 = MyData, .俳句英 = MyKuEnglish})
        Next
        MyDailyHaikuListBox.ItemsSource = MyKuList

    End Sub

    '■「昇順ソート」ボタンがタップされた時の処理
    Private Sub SortAscendingButton_Tap(sender As Object, e As System.Windows.Input.GestureEventArgs) Handles SortAscendingButton.Tap

        '●「昇順ソート」ボタンを使用不可とし、「降順ソート」ボタンを使用可とする
        SortAscendingButton.Opacity = 0.3
        SortAscendingButton.IsEnabled = False

        SortDscendingButton.Opacity = 1.0
        SortDscendingButton.IsEnabled = True

        '●昇順ソート表示の処理を実行
        SortAscending()
    End Sub

    '■「降順ソート」ボタンがタップされた時の処理
    Private Sub SortDscendingButton_Tap(sender As Object, e As System.Windows.Input.GestureEventArgs) Handles SortDscendingButton.Tap

        '●「降順ソート」ボタンを使用不可とし、「昇順ソート」ボタンを使用可とする
        SortDscendingButton.Opacity = 0.3
        SortDscendingButton.IsEnabled = False

        SortAscendingButton.Opacity = 1.0
        SortAscendingButton.IsEnabled = True

        '●降順ソート表示の処理を実行
        SortDescending()
    End Sub

End Class
